.. _notebooks:

Notebooks
================

Some notebooks are prepared for the example analysis.

.. nbgallery::
   pykegg-intro.ipynb
   pykegg-parallel-edges.ipynb
   single-cell-example.ipynb
   use-with-pydeseq2.ipynb
   drawing-global-map.ipynb
   vis-multiple-enrichment.ipynb